function [score] = range_estimation_error(actual, predic, ran_num)

% [score] = range_estimation_error(actual, predic)
% 
% This function calculates the range estimation error (mean absolute 
% error / range of the vector)
%
% actual    - actual data
% predic    - predicted data
% max_num   - range number to divide MAE
%
% score     - range estimation error
%
%
%
% --
% ing. Zoltán Galáž
% xgalaz00@stud.feec.vutbr.cz       
% 
% Department of Telecommunications
% Faculty of Electrical Engineering and Communication
% Brno University of Technology

%% Calculate the maximum estimation error
score = (mean_absolute_error(actual, predic)/ran_num)*100;